# SPAM-DFBA

## Introduction

SPAM-DFBA is an algoritm for inferring microbial interactions by modeling microbial metabolism in a community as a decision making process, a markov decision process more specifically, where individual agents learn metabolic regulation strategies that lead to their long-term survival by trying different strategies and improve their strategies according to proximal policy optimization algorithm.

***More information can be found in the documentation website for this project:***

https://chan-csu.github.io/SPAM-DFBA/

## Installation

There are multiple ways to install SPAM-DFBA. Before doing any installation it is highly recomended that you create a new environment for this project.
After creating the virtual environment and activating it, one way for installation is to clone the ripository and pip install from the source files:

```

git clone https://github.com/chan-csu/SPAM-DFBA.git
cd SPAM-DFBA
pip install .

```
Another approach is to directly install this package from pipy:

```
pip install spamdfba
```

## Examples

The examples used in the manuscript are provided in separated jupyter notebooks in the ./examples directory. Additionally, they are provided in the documentation website for this project under Case Study-* section


## Contribution

If you have any suggestions or issues related to this project please open an issue or suggest a pull request for further imrovements!







